@@ -117,6 +117,19 @@ class CliParser:
             type=feed_type,
             help="Select which feed should be synced. (Default: %(default)s)",
         )
+        parser.add_argument(
+            "--feed-version",
+            help="Deprecated. Use --feed-release instead.",
+        )
+        parser.add_argument(
+            "--feed-release",
+            help="Release series of the feed to download for example 22.04 or 24.10. (Default: %(default)s)",
+        )
+        parser.add_argument(
+            "--destination-prefix",
+            type=Path,
+            help="Prefix for the destination directories. (Default: %(default)s)",
+        )
         parser.add_argument(
             "--gvmd-data-destination",
             type=Path,
@@ -125,8 +138,7 @@ class CliParser:
         )
         parser.add_argument(
             "--gvmd-data-url",
-            help="URL to download the gvmd data from. "
-            "(Default: %(default)s)",
+            help="URL to download the gvmd data from. (Default: %(default)s)",
         )
         nvts_destination_group = parser.add_argument_group()
         nvts_destination_group.add_argument(
@@ -138,8 +150,7 @@ class CliParser:
         nvts_url_group = parser.add_argument_group()
         nvts_url_group.add_argument(
             "--notus-url",
-            help="URL to download the notus data from. "
-            "(Default: %(default)s)",
+            help="URL to download the notus data from. (Default: %(default)s)",
         )
         nvts_destination_group.add_argument(
             "--nasl-destination",
@@ -149,8 +160,7 @@ class CliParser:
         )
         nvts_url_group.add_argument(
             "--nasl-url",
-            help="URL to download the nasl data from. "
-            "(Default: %(default)s)",
+            help="URL to download the nasl data from. (Default: %(default)s)",
         )
 
         secinfo_destination_group = parser.add_argument_group()
@@ -163,8 +173,7 @@ class CliParser:
         secinfo_url_group = parser.add_argument_group()
         secinfo_url_group.add_argument(
             "--scap-data-url",
-            help="URL to download the SCAP data from. "
-            "(Default: %(default)s)",
+            help="URL to download the SCAP data from. (Default: %(default)s)",
         )
         secinfo_destination_group.add_argument(
             "--cert-data-destination",
@@ -174,8 +183,7 @@ class CliParser:
         )
         secinfo_url_group.add_argument(
             "--cert-data-url",
-            help="URL to download the CERT data from. "
-            "(Default: %(default)s)",
+            help="URL to download the CERT data from. (Default: %(default)s)",
         )
 
         data_objects_destination_group = parser.add_argument_group()
@@ -342,6 +350,15 @@ class CliParser:
                 known_args.greenbone_enterprise_feed_key
             )
 
+        if known_args.feed_version:
+            config["feed-release"] = known_args.feed_version
+
+        if known_args.feed_release:
+            config["feed-release"] = known_args.feed_release
+
+        if known_args.destination_prefix:
+            config["destination-prefix"] = known_args.destination_prefix
+
         if self.parser.prog == "greenbone-nvt-sync":
             config["type"] = "nvt"
         elif self.parser.prog == "greenbone-scapdata-sync":
